==> haskell-storable-complex-0.2.3.0-313-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-BiH4zXxStJn9zWmlr5flmB
key:                  storable-complex-0.2.3.0-BiH4zXxStJn9zWmlr5flmB
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  64ab09a69cee869bea6fe0d80d03981f
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-complex
hs-libraries:         HSstorable-complex-0.2.3.0-BiH4zXxStJn9zWmlr5flmB
depends:
    base-4.17.2.1 base-orphans-0.9.3-jrebtQe5Zr9GOzaUAatCY

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-complex-0.2.3.0-314-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-GSSQ8MhEj3F1zyFBsVU4IF
key:                  storable-complex-0.2.3.0-GSSQ8MhEj3F1zyFBsVU4IF
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  cd7d761124c363ecb6c8cafcdb307d7a
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-complex
hs-libraries:         HSstorable-complex-0.2.3.0-GSSQ8MhEj3F1zyFBsVU4IF
depends:
    base-4.17.2.1 base-orphans-0.9.3-4AvA3HBpg1d8SzdmnVJk30

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
